Package: eudysbiome
Type: Package
Title: Cartesian plot and contingency test on 16S Microbial data
Version: 1.43.0
Date: 2016-05-19
Author: Xiaoyuan Zhou, Christine Nardini
Maintainer: Xiaoyuan Zhou <zhouxiaoyuan@picb.ac.cn>
Description: eudysbiome a package that permits to annotate the differential
    genera as harmful/harmless based on their ability to contribute to host
    diseases (as indicated in literature) or unknown based on their ambiguous
    genus classification. Further, the package statistically measures the eubiotic
    (harmless genera increase or harmful genera decrease) or dysbiotic(harmless
    genera decrease or harmful genera increase) impact of a given treatment or
    environmental change on the (gut-intestinal, GI) microbiome in comparison to the
    microbiome of the reference condition.
Depends: R (>= 3.1.0)
Imports: plyr, Rsamtools, R.utils, Biostrings
License: GPL-2
LazyData: TRUE
RoxygenNote: 5.0.1
git_url: https://git.bioconductor.org/packages/eudysbiome
git_branch: devel
git_last_commit: 33f2ad5
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 22:34:15 UTC; biocbuild

# Generated by roxygen2: do not edit by hand

export(Cartesian)
export(assignTax)
export(contingencyCount)
export(contingencyTest)
export(microAnnotate)
export(tableSpecies)
import(Biostrings)
import(plyr)
importFrom(R.utils,getAbsolutePath)
importFrom(R.utils,gunzip)
importFrom(Rsamtools,FaFile)
importFrom(Rsamtools,getSeq)
importFrom(Rsamtools,indexFa)
importFrom(Rsamtools,seqinfo)

#' Genus Annotation
#'
#' Annotates given genera as harmful or harmless based on either our manually curated, harmful Genus-Species table in data \code{harmGenera} of this package or user defined table.
#' @usage microAnnotate(microbe, species = TRUE, annotated.micro = NULL)
#'
#' @param microbe a genus list to be annotated; a Genus-Species data frame which represents the genera and the included corresponding species is recommended to be provided by users for the more accurate annotations, see \code{\link{tableSpecies}}.
#' @param species logical, specifying if the species are provided in the \code{microbe} for the annotations; default to \code{TRUE}.
#' @param annotated.micro the annotated genera which are used for the annotation of \code{microbe}, it could either be loaded from the data \code{harmGenera} or defined by users.
#' @return The annotated genera.
#' @export
#' @examples
#' #load the genera to be annotated
#' library(eudysbiome)
#' data(diffGenera)
#'
#' #load the curated Genus-Species annotation table
#' data(harmGenera)
#'
#' microAnnotate(microbe = diffGenera, species = TRUE,
#'            annotated.micro = harmGenera)


microAnnotate = function(microbe,species =TRUE,annotated.micro = NULL){

  if(is.null(annotated.micro)){
    annotated.micro = data(harmGenera)
    annotated.micro = annotated.micro[,c("Genus","Species")]
  }

  if (species){
    if(!is.data.frame(microbe)){
    	microbe = data.frame(microbe)
    }
    microbe = microbe[!is.na(microbe$Species) | is.na(microbe$Species) & !microbe$Genus %in% annotated.micro$Genus,] 

    #get harmful genera matched to the annotated.micro table
    match = merge(microbe,annotated.micro)

    #get harmless genera
    difference = microbe[!microbe$Genus %in% match$Genus,]
    
    #annotate the harmful and harmless genera
    if (nrow(match) != 0){
    	 match$micro.anno = "harmful"
    	 }
    difference$micro.anno ="harmless"
         
    #integrate all annotated genera
    annotated.microbe = rbind(match,difference)
    annotated.microbe = unique(annotated.microbe)
    annotated.genera = unique(annotated.microbe[,c("Genus","micro.anno")])
    }
    else{
    	if(is.data.frame(microbe))
    	microbe = microbe$Genus
    	match = intersect(microbe,unique(annotated.micro$Genus))
    	match = data.frame(Genus = match, micro.anno ="harmful")

    difference = setdiff(microbe,unique(annotated.micro$Genus))
    difference = data.frame(Genus = difference,micro.anno="harmless")

    annotated.genera = rbind(match,difference)
  }
  return (list(genera= annotated.genera,microbe=annotated.microbe))
}

#' Construct a Genus-Species Data Frame
#'
#' This function is used to extract only Genus-Species data from the assigned taxonomic paths outputted by \code{\link{assignTax}} and construct a table containing the classified genera and species included in these genera correspondingly.
#' @usage tableSpecies(tax.file, microbe)
#' @param tax.file a taxonomy file with SSU rRNA sequence names and assigned taxonomic paths, see "*.taxonomy" file outputted by \code{\link{assignTax}}.
#' @param microbe a character vector specifying the genera used to construct the Genus-Species data frame
#' @return a Genus-Species data frame, only with the genera specified by \code{microbe} and the included corresponding species .
#' @details The outputted Genus-Species table can be used as input for the more accurate genus annotation, which annotates genera as \code{harmful} or \code{harmless} based on their ability to contribute to mammals' host diseases by \code{\link{microAnnotate}}.
#' @export
#' @examples
#' #a table with "Lactobacillus" and "Bacteroids" genera and the included species
#' genera = c("Lactobacillus","Bacteroides")
#' #not excute
#' #tableSpecies(tax.file = "test.taxExtract.wang.taxonomy", microbe = genera)


tableSpecies = function(tax.file,microbe){
  tax =read.table(tax.file,as.is=T,sep="\t")
  colnames(tax) = c("SeqID","Tax")

  split = strsplit(as.character(tax$Tax),";")
  tax.all = do.call(rbind,split)
  tax.all = data.frame(tax.all,stringsAsFactors = F)
  colnames(tax.all) = c("Kingdom","Phylum","Class","Order","Family","Genus","Species")

  #replace "_" to " " in species column
  tax.all$Species = gsub("(_)([[:alpha:]])", " \\U\\2", tax.all$Species, perl=TRUE)

  #get genus-species data frame for the differential microbes
  species = tax.all[,c("Genus","Species")]
  species = unique(species)

  #filter the ambiguous classified species
  iterms = c("nculture","Sp[.]", " Gut Metagenome","nidentified","Bacterium_","nclassified","^bacterium"," fecal$")
  matches = grepl(paste(iterms,collapse="|"), species$Species)
 
  species = species[!matches,]
  species$Species = sapply(species$Species, function(x){
  	split = unlist(strsplit(x," "))
  	len = length(split)
  	if(len == 1){
  		y = split[[1]]
  	}
  	else{
  		y = paste( split[1:2],collapse =" ")
  	}
  	return(y)
  	})

  diffSpecies = species[species$Genus %in% microbe,]
  unmatched = setdiff(microbe, diffSpecies$Genus)
  if(length(unmatched) != 0){
  	unmatched_genus = data.frame(Genus=unmatched,Species=NA)
  }
  else{
  	unmatched_genus = NULL
  	}
  
  diffSpecies = rbind(diffSpecies,unmatched_genus)
  diffSpecies$Species = gsub("( )([[:upper:]])","\\1\\L\\2",diffSpecies$Species,perl=TRUE)
  rownames(diffSpecies) = NULL
  
  matches = grepl(paste(iterms,collapse="|"), diffSpecies$Species)
  diffSpecies = diffSpecies[!matches,]
  diffSpecies = unique(diffSpecies)
  
  return(species=diffSpecies)
}

#' Contingency test for count data
#'
#' Performs Chi-squared test or Fisher's exact test for testing the significance of association between conditions and eubiotic/dysbiotic impacts in a contingency table.
#' @usage contingencyTest(microCount, chisq = TRUE, fisher = TRUE,
#'                 alternative = c("greater"))
#' @param microCount a \emph{m by 2} data frame or numeric matrix of contingency table with frequencies under each condition-impact term; could be produced from \code{\link{contingencyCount}}.
#' @param chisq,fisher logical indicating if the Chi-squared test or Fisher's exact test should be performed.
#' @param alternative parameter specifying for alternative hypothesis, only used when \code{fisher} is \code{TRUE}; see \code{\link[stats]{fisher.test}}.
#' @details Chi-squared test for testing the probability that  the proportions of eubiotic frequencies are different between two conditions; furtherly, the Fisher's exact test for testing whether one condition is more likely to be associated to eubiotic impact. More details, refer to \code{\link[stats]{chisq.test}} and \code{\link[stats]{fisher.test}}
#' @return A list with following components:
#' Chisq Chi-squared test results for each pair-wise condition.
#' Chisq.p the p-values of the Chi-squared tests for all pair-wise conditions.
#' Fisher Fisher's exact test results for each pair-wise condition.
#' Fisher.p the p-values of the Fisher's exact tests for all pair-wise conditions.
#' @export
#' @seealso \code{\link{contingencyCount}}, \code{\link[stats]{fisher.test}}, \code{\link[stats]{chisq.test}}
#' @examples
#' data(microCount)
#'
#' test = contingencyTest(microCount,chisq = TRUE,fisher = TRUE,
#'            alternative = "greater")
#' chisq.p = test[["Chisq.p"]]
#' fisher.p = test[["Fisher.p"]]

contingencyTest = function(microCount, chisq = TRUE, fisher =TRUE,
                           alternative=c("greater"))
{
  if(!is.data.frame(microCount))
    microCount = data.frame(microCount)
  if ( nrow(microCount) == 2){
    condition.pair = cbind(microCount[1,],microCount[2,])
    rownames(condition.pair) = paste(rownames(microCount),collapse=":")
  }
  else {
    conditions = rownames(microCount)
    condition_pairs <- combn(nrow(microCount),2)
    condition.pair = cbind(microCount[condition_pairs[1,],],microCount[condition_pairs[2,],])
    for ( i in 1:nrow(condition.pair)){
      row.names(condition.pair)[i] = paste(conditions[condition_pairs[,i]],collapse =":")
    }
  }

  ## choose the method before association test

  #if(!is.data.frame(microCount.pair))
  #microCount.pair = data.frame(microCount.pair)

  if(chisq)
  {
    chi.test = apply(condition.pair,1,function(x){
      sum = sum(x)
      y= matrix(x,nrow=2,byrow=TRUE)
      if( sum >= 40 && all(x >= 5))
        chisq.test(y)
      else if (sum >= 40 && all(x >=1) && any(x < 5))
        chisq.test(y,correct=TRUE)
      else
        NA
    })

    chi.p = apply(condition.pair,1,function(x){
      y= matrix(x,nrow=2,byrow=TRUE)
      sum = sum(x)
      if( sum >= 40 && all(x >= 5))
        chisq.test(y)$p.value
      else if (sum >= 40 && all(x >=1) && any(x < 5))
        chisq.test(y,correct=TRUE)$p.value
      else
        NA
    })
    Chisq.p= data.frame("Chisq.Pvalue" = chi.p)
  }


  if(fisher){
    fisher.test = apply(condition.pair,1,function(x){
      sum = sum(x)
      y= matrix(x,nrow=2,byrow=TRUE)
      fisher.test(y,alternative =alternative)
    })

    fisher.p = apply(condition.pair,1,function(x){
      y= matrix(x,nrow=2,byrow=TRUE)
      sum = sum(x)
      fisher.test(y,alternative =alternative)$p.value
    })
    name = paste("Fisher.Pvalue",alternative,sep="_")
    Fisher.p= data.frame(fisher.p)
    colnames(Fisher.p) = name
  }
  
  if(chisq && fisher){
  	RESULT = list(Chisq = chi.test,Chisq.p = Chisq.p, Fisher = fisher.test,Fisher.p=Fisher.p)
  }
  else if (chisq){
  	RESULT = list(Chisq = chi.test,Chisq.p = Chisq.p)
  }
  else{
  	RESULT = list(Fisher = fisher.test,Fisher.p=Fisher.p)
  	}  	
  return (RESULT)
}

#' 2-D Cartesian plane Plots
#'
#' This function plots a Cartesian plane of genus abundance difference across the tested conditions (y-axis) and their harmful/harmless nature (negative/positive x-axis), giving rise to up-utmost right and bottom-utmost left quadrants of microbial eubiotic impact and bottom-utmost right and up-utmost left quadrants of dysbiotic impact.
#' @usage Cartesian(x,log2 = TRUE,micro.anno = NULL, comp.anno = NULL,
#'              pch = 16, point.col = NULL,point.alpha = 0.6,ylim = NULL, 
#'              xlab = NULL,ylab = NULL,vlty = 2, hlty = 1, srt = 60,
#'              font = 3, adj = c(1,1), xaxis = NULL, yaxis = NULL, legend = TRUE,
#'              box = TRUE,box.col = c("darkblue","yellow"),
#'              ...)
#'
#' @param x a data frame or numeric matrix of microbial abundance variations from which the plot is produced. Rows indicate the differential microbes, columns indicate the pair-wise conditions. \code{x} values can either be difference values or be \emph{log2} converted, specified with \code{log2} parameter.
#' @param log2 logical, specifying if x values should be \emph{log2} converted; default to \code{TRUE}.
#' @param micro.anno a character vector to annotate all row microbes in \code{x}; e.g. \code{"harmless"},\code{"harmful"}, should be in same length with the microbes. It can be given by the output of \code{\link{microAnnotate}}
#' @param comp.anno a character vector of conditions pre-defined from the column pair-wise comparisons, should be in same length with the comparisons; default to the pair-wise comparisons.
#' @param pch a vector of point types. Graphical parameters:see \code{\link[graphics]{par}}.
#' @param point.col a vector of colors for the points.
#' @param point.alpha alpha value for points; see \code{\link[grDevices]{adjustcolor}}.
#' @param ylim limits for the y axis.
#' @param xlab a title for the x axis.
#' @param ylab a title for the y axis.
#' @param vlty,hlty types of vertical and horizontal lines to divide the plane with x-axis and y-axis, respectively.
#' @param srt,font,adj graphical parameters for the text on x-axis, see \code{\link[graphics]{par}}.
#' @param xaxis a character or expression vector specifying the labels of x axis by \emph{text}; default to row names of \code{x}.
#' @param yaxis a character or expression vector specifying the labels of y axis by \emph{axis}; default to \code{at} values in \code{\link[graphics]{axis}}.
#' @param legend logical, specifying if the legend should be added to the plot; default to \code{TRUE}.
#' @param box logical, specifying if the quadrants should be highlighted by boxes; default to \code{TRUE}.
#' @param box.col a vector of colors for the  up-utmost right, bottom-utmost left quadrants and bottom-utmost right, up-utmost left quadrants, respectively; default to "darkblue" and "yellow". If only one color is specified, the other one can be \code{NA}.
#' @param ... additional parameters passed to the default method, or by it to \code{\link[graphics]{plot.window}}, \code{\link[graphics]{text}},\code{\link[graphics]{mtext}},\code{\link[graphics]{axis}}, and \code{\link[graphics]{title}} to control the appearance of the plot.
#' @return The Cartesian plane plot
#' @export
#' @examples
#' data(microDiff)
#' attach(microDiff)
#'
#' newpar = par()
#' par(mar = c(6,5.1,4.1,6))
#' Cartesian(x = data,log2 = TRUE,micro.anno = micro.anno,pch = 16,
#'          comp.anno = comp.anno,point.col = c("blue","purple","orange"))
#'
#' par(newpar)
#' detach(microDiff)

Cartesian = function(x,log2 =TRUE,micro.anno=NULL, comp.anno=NULL,pch=16, point.col= NULL,
                           point.alpha =0.6, ylim=NULL, xlab=NULL,ylab=NULL,
                           vlty= 2, hlty = 1, srt =60, font=3, adj=c(1,1),
                           xaxis=NULL, yaxis=NULL, legend = TRUE, box=TRUE,
                           box.col =c("darkblue","yellow"),...)
{
  #check the input x
  if (!is.data.frame(x) && !is.matrix(x))
    stop("'x' must be a data frame or numeric matrix")

  if (is.null(colnames(x))) stop ("Comparison names are missing!")
  if (is.null(rownames(x))) stop ("Genera names are missing!")

  #micro.anno and comp.anno
  if (is.null(micro.anno)){
    stop ("Microbial annotations are missing")
  } else if(length(micro.anno) != nrow(x)){
    stop ("Microbe annotations don't match rows of x")
  } else {
    x$micro.anno= micro.anno
    ano = c("harmful","harmless")
    x = x[with(x,order(match(micro.anno,ano))),]

    micro.anno = x$micro.anno
    x = x[,-which(colnames(x) %in% "micro.anno")]
  }

  di <- dim(x)
  nr <- di[1]
  nc <- di[2]
  if(nr <= 1 || nc <= 1)
    stop("'x' must have at least 2 rows and 2 columns")

  x[is.na(x)]= NULL

  # log2 convert the abundanace difference
  if(log2){
    for (m in 1:nr){
      for ( n in 1:nc){
        if (x[m,n] ==0)
          x[m,n] = 0
        else if (x[m,n] < 0 )
          x[m,n]= -log(abs(as.numeric(x[m,n])),base =2)
        else
          x[m,n] = log(as.numeric(x[m,n]),base =2)
      }
    }
  }

  min = floor(range(x,na.rm=TRUE))[1]
  max = ceiling(range(x,na.rm=TRUE))[2]


  if (is.null(comp.anno)){
    comp.anno = colnames(x)
  } else if (length(comp.anno) != nc){
    stop ("Comparison pre-definations don't match columns of x")
  }


  # micro.tab <- table(factor(micro.anno,levels<-unique(micro.anno)))


  if(is.null(point.col)){
    point.col = adjustcolor(sample(colors(),nc),alpha.f = point.alpha)
  } else
    point.col =  adjustcolor(point.col,alpha.f =point.alpha)

  if (length(point.col) && length(point.col) != nc)
    stop ("Incorrect number of point.col")

  if (is.null(ylim))
    ylim <- c(min,max)

  # set the vertical and horizontal lines
  vline = length(micro.anno[micro.anno == "harmful"]) + 0.5
  hline <- 0

  if(is.null(xlab))
    xlab = c(rep("",nr))
  if (is.null(ylab))
    ylab =expression(paste('log'[2],Delta*g,sep=""))


  ## Output Graphics
  dev.hold()
  on.exit(dev.flush())
  
  #circle diameter is represented by log2-x values
  cex = abs(x)
  # par(mar=c(13,5.1,4.1,6), adj= 0.5, cex.axis= 1,cex.lab =1.1)

  plot(x[,1],ylim = ylim,pch =pch,cex = cex[,1],col = point.col[1], xaxt ="n",yaxt="n",las=0,xlab="", ylab=ylab,cex.lab=1.2,...)
  for(i in 2:nc){
    points(x[,i],cex=cex[,i],pch =pch,col= point.col[i])
  }
  abline(h=hline,v=vline,lty=c(hlty,vlty))

  #add ylabs
  if (!is.null(yaxis)){
    axis(2,at=yaxis,labels =yaxis,cex.axis=1.2,...)
  } else{
    axis(2,at=seq(0,min(ylim),-2),labels=seq(0,min(ylim),-2),cex.axis=1.2,...)
    axis(2,at=seq(0,max(ylim),2),labels=seq(0,max(ylim),2),cex.axis=1.2,...)
  }

  #add xlabs
  axis(1,at=seq(1,nr,1),labels=xlab)
  if(!is.null(xaxis)){
    text(seq(1,nr,1),par("usr")[3]-0.3,labels=xaxis,srt=srt,xpd=TRUE,font=font,adj=adj,cex=1.2,...)
  } else
    text(seq(1,nr,1),par("usr")[3]-0.3,labels=rownames(x),srt=srt,xpd=TRUE,font=font,adj=adj,cex=1.2,...)


  mtext("harmful",side=3,at= 1,adj=0,cex=1.3,...)
  mtext("harmless",side=3,at=nr, adj=1,cex=1.3,...)

  #add title or legend
  title(...)
  border = par("usr")
  if(legend){
    legend(border[2],border[4],legend=comp.anno,bty="n",col=point.col,pch=pch,xpd=TRUE,pt.cex=1.5,cex=1)
  }


  #darkblue box for the eubiotic impact and yellow box for the dysbiotic impact
  if(box){
  	 rect(border[1]+0.1,border[3]+0.1,vline-0.1,0-0.1,lwd=3.5,border=box.col[1])
    rect(vline+0.1,0+0.1,border[2]-0.1,border[4]-0.1,lwd=3.5,border= box.col[1])
    rect(border[1]+0.1,0+0.1,vline-0.1,border[4]-0.1,lwd=3.5,border= box.col[2])
    rect(vline+0.1,border[3]+0.1,border[2]-0.1,0-0.1,lwd=3.5,border= box.col[2])
  }
   }

#' Taxonomic Classification
#'
#' Assign taxonomic paths to unclassified SSU rRNA sequences, by executing \code{classify.seqs} in \href{http://www.mothur.org/}{Mothur} with the 'Wang' approach.
#' @usage assignTax(fasta, template = NULL, taxonomy = NULL, ksize = 8, iters = 100, cutoff = 80,
#' processors = 1, dir.out = "assignTax_out")
#'
#' @param fasta a fasta file of rRNA sequences to be assigned with taxonomies, e.g. a set of sequences picked as the representatives of OTUs.
#' @param template a faste file of rRNA reference sequences, default to download "Silva_132_release.zip" under "qiime" directory from SILVA archive under , and extract "Silva_132_rep_set97.fna", a representative set of SILVA rRNA references of version132 at 97\% sequence identity.
#' @param taxonomy a taxonomic path file mapping to the template file, default to load "Silva_132_rep_set97.fna" matched "taxonomy" stored in the package.
#' @param ksize,iters,cutoff,processors parameters used in \href{http://www.mothur.org/wiki/Classify.seqs}{Classify.seqs} by Mothur. \code{ksize}, kmer size which is a search option with the 'Wang' method and by default to 8.  \code{iters}, iterations by default 100 to calculate the bootstrap confidence score for the assigned taxonomy. \code{cutoff}, a bootstrap confidence score for the taxonomy assignment, by default 80, which means a minimum 80\% sequences were assigned by the same taxonomy, a higher value gives a more strict taxonomy assignment. \code{processors}, the number of central processing units you use to run the command, by default to 1.
#' @param dir.out a directory where the assigned files were outputted, by default to create \code{assignTax_out} directory and output assigned files under this directory.
#' @details This function performs 'classify.seqs' by running Mothur in command line mode, hence the executable Mothur on your computer is needed. For unix users, the absolute path of Mothur should be added to the PATH environmental variable and exported. For Windows users, the executable Mothur with extension .exe is required under your disks.
#' @export
#' @return two files under \code{dir.out}, a \code{*.taxonomy} file which contains a taxonomic path for each sequence and a \code{*.tax.summary} file which contains a taxonomic outline indicating the number of sequences that were found at each level (kingdom to species).
#' a list containing the following components:
#' exitStatus  an error code ('0' for success) given by the execution of the system Mothur commands, see \code{\link[base]{system}}.
#' stderr, stdout standard errors and outputs by executing Mothur command 'classify.seqs'.

assignTax = function(fasta, template=NULL, taxonomy=NULL, ksize = 8,
iters = 100, cutoff = 80, processors=1, dir.out = "assignTax_out") {
  #dir.out = "assignTax_out"
	if (!is.na(dir.out) | !is.null(dir.out) | !is.nan(dir.out)) {
		dir.create(dir.out, recursive = T, showWarnings = F)
	}
	
	#download the template file
	if(is.null(template)){
		t.file = "http://www.arb-silva.de/fileadmin/silva_databases/qiime/Silva_132_release.zip"
		temp = tempfile()
		download.file(t.file,destfile = temp, method="curl")
		unzip(temp, "Silva132_release/rep_set/97/Silva_132_rep_set97.fna")
		template = "Silva132_release/rep_set/97/Silva_132_rep_set97.fna"
		unlink(temp)
	}
	if(is.null(taxonomy)){
		taxonomy.file = system.file("Rep/Silva_132_rep_set97_taxonomy.txt.bz2", package = "eudysbiome")
		bunzip2(taxonomy.file)
		taxonomy = getAbsolutePath("Silva_132_rep_set97_taxonomy.txt")
	}
	if (.Platform$OS.type == "unix") {
		exec = "mothur"
		exec.path = Sys.which(exec)
		if (exec.path == "") {
		stop("Executable mothur is not found.")
		}
		cmd1 = paste(exec.path, " \"#set.dir(output=", dir.out, ")", sep = "")
		}
		else{
			exec = paste(exec,".exe",sep="")
			disks = system("cmd.exe /c wmic logicaldisk caption", intern=TRUE)
			disks = gsub("(.*:).*","\\1",disks)
			matched = grepl(":",disks)
			disks = disks[matched]

		for(i in seq_along(disks)){
			cmd = paste("cmd.exe /c where /r ",disks[i], "\\ ", exec ,sep="")
			cmd.out = system(cmd,show.output.on.console=FALSE)
			if(cmd.out == 0){
				break
			}
		}
		if(cmd.out !=0){
			stop("Executable mothur is not found.")
		}
		else{
		exec.path=system(cmd,intern=TRUE)
		cmd1 = paste("cmd.exe /c ",exec.path, " \"#set.dir(output=", dir.out, ")", sep = "")
		}
		}

	stderr.file = tempfile(pattern = "stderr", fileext = as.character(Sys.getpid()))
	stdout.file = tempfile(pattern = "stdout", fileext = as.character(Sys.getpid()))

	cmd2 = paste("classify.seqs(fasta=", fasta,
	",template=", template,
	",taxonomy=", taxonomy,
	",ksize=", ksize,
	",iters=", iters,
	",cutoff=", cutoff,
	",processors=", processors,
	",probs=FALSE", ")\"", " 2> ", stderr.file, " > ", stdout.file, sep = "")

	cmds = paste(cmd1, cmd2, sep = "; ")

	retval = list()

	retval$exitStatus = system(cmds)

	#if (retval$exitStatus != 0) {
	#	stop("Error in mothur execution.")
	#}

	retval$stderr = readLines(stderr.file)
	retval$stdout = readLines(stdout.file)
	unlink(c(stdout.file, stderr.file))
	return(retval)
}

#' Contingency Table Construction
#'
#' Computes the frequencies of the contingency table as the cumulated microbial abundance difference classified into each condition and eubiotic/dysbiotic impact term for examining the significance of the association (contingency) between conditions and impacts by  \code{\link{contingencyTest}}.
#' @usage contingencyCount(x, micro.anno=NULL, comp.anno=NULL)
#'
#' @param x See \code{x} in \code{\link{Cartesian}}, the x values should be difference values without log converted.
#' @param micro.anno See \code{micro.anno} in \code{\link{Cartesian}}.
#' @param comp.anno See \code{comp.anno} in \code{\link{Cartesian}}.
#' @details Eubiotic impact is measured by variations of increased harmless and decreased harmful microbes, while the dysbiotic impact is measured by the decreased harmless and increased harmful microbes.
#' @return The frequencies of condition-impact terms in contingency table
#' @export
#' @examples
#' data(microDiff)
#' attach(microDiff)
#'
#' microCount = contingencyCount(x = data, micro.anno = micro.anno,
#'                       comp.anno = comp.anno)
#'
#' detach(microDiff)


contingencyCount = function(x, micro.anno=NULL,comp.anno =NULL)
{

  if (!is.data.frame(x) && !is.matrix(x))
    stop("'x' must be a data frame or numeric matrix.")

  if (is.null(comp.anno))
    stop ("Comparsion annotations are missing!")
  else if (length(comp.anno) != ncol(x))
    stop ("Comparison annotations don't match columns of 'x'.")


  if (is.null(micro.anno))
    stop ("Microbial annotations are missing")
  else if (length(micro.anno) != nrow(x))
    stop ("Microbe annotations don't match rows of x")

  if ("unknown" %in% micro.anno){
    x$micro.anno = micro.anno
    x= x[x$micro.anno != "unknown",]
  }
  else
    x$micro.anno = micro.anno

  colnames(x) = c(comp.anno,"micro.anno")

  ## make the count matrix for the association test
  microCount = matrix(NA,length(comp.anno),2)
  rownames(microCount) = comp.anno
  colnames(microCount) = c("EI","DI")

    for(i in 1:nrow(microCount))
    {
      pc1 = x[x$micro.anno == "harmless",colnames(x) %in% rownames(microCount)[i]]
      pc2 = x[x$micro.anno == "harmful",colnames(x) %in% rownames(microCount)[i]]
      pcount1 = sum(pc1[pc1>0],na.rm=TRUE)
      pcount2 =abs(sum(pc2[pc2<0],na.rm =TRUE))
      microCount[i,"EI"] = pcount1 + pcount2
      ncount1 = abs(sum(pc1[pc1 < 0],na.rm=TRUE))
      ncount2 =sum(pc2[pc2 >0],na.rm =TRUE)
      microCount[i,"DI"] = ncount1 + ncount2
    }
    return(microCount)
}

#' eudysbiome.
#'
#' @name eudysbiome
#' @docType package
#' @import plyr Biostrings
#' @importFrom R.utils gunzip getAbsolutePath
#' @importFrom Rsamtools indexFa FaFile seqinfo getSeq

NULL

#' Manually curated genera annotation table
#' A data frame containing 260 genera annotated as "harmful" and the harmful species included in these genera.
#'
#' @docType data
#' @keywords datasets
#' @name harmGenera
#' @usage data(harmGenera)
#' @format A data frame with 900 rows and 3 columns specifying for \code{Genus} and \code{Species} and the references.
NULL

#' Differential microbes in Genus-Species table
#' A data frame containing 10 differential genera and the species included, which was to be annotated as \code{"harmful"} or \code{"harmless"}.
#'
#' @docType data
#' @keywords datasets
#' @name diffGenera
#' @usage data(diffGenera)
#' @format A data frame with 26 rows and 2 columns specifying for \code{Genus} and \code{Species}.
NULL


#' Differential annotated genera with abundance variations among pair-wise condition comparisons
#'
#' A list containing: i) a data frame of 10 differentila genera with abundance differences among 3 condition comparisons, in which row represents the differential microbes and column represents the comparisons; ii) Genera annotations for the 10 differential genera; iii) pre-defined condition comparison names
#'
#' @docType data
#' @keywords datasets
#' @name microDiff
#' @usage data(microDiff)
#' @format A list
NULL


#' Microbial count contingency table
#'
#' A matrix containing the counts of differential microbe classified into each condition-eubiotic/dysbiotic impact couple. Rows represent the condition comparisons, columns represent the eubiotic and dysbiotic impacts:
#'
#' \itemize{
#'   \item EI. eubiotic impact
#'   \item DI. dysbiotic impact
#' }
#'
#'The table can be produced by \code{\link{microCount}} function.
#'
#' @docType data
#' @keywords datasets
#' @name microCount
#' @usage data(microCount)
#' @format A data frame with 2 rows and 2 variables
NULL

\documentclass[11pt]{article}
%\VignetteIndexEntry{eudysbiome User Manual}
%\VignettePackage{eudysbiome}
\usepackage{hyperref}
\usepackage{enumerate}

\textwidth=6.2in
\textheight=8.7in
\oddsidemargin=0.2in
\evensidemargin=0.2in
\headheight=0in
\headsep=0in
\large

\begin{document}
\SweaveOpts{concordance=TRUE}

\title{eudysbiome User Manual}
\author{Xiaoyuan Zhou, Christine Nardini \\
zhouxiaoyuan@picb.ac.cn}

\maketitle

\section*{Introduction}
\label{sec:introduction}

Large amounts of data for metagenomics, especially the earliest studies on 16S ribosomal RNA gene, are produced by high-throughput screening methods. These are processed in the form of quantitative comparisons (between two microbiomes' conditions) of reads' counts. Reads' counts are interpreted as a taxon's \texttt{abundance} in a microbial community under given conditions, such as a medical treatments or environmental changes. The comparative analysis of such microbiomes with a baseline condition permits to identify a list of microbes (classified in species, genus or higher-order taxa) that are differential in abundance among the conditions. The taxonomic classification of 16S rRNA sequences is generally dependent on two strategies to assign sequences into populations: one is the phylotype-based method that assigns sequences to taxa based on the similarity to a reference database; the other is the operational taxonomic unit (OTU)-based method which does not rely on the association to known taxa, but consists of the definition of clusters of sequences sharing high similarity among them (typically a 97\% identity threshold). These clusters are identified by an OTU\_ID, and where possible associated to a species. The phylotype-based method limits the taxonomic classification of novel sequences from previously unknown taxa and is less sensitive to the sequencing errors\cite{Schloss2011}. The OTU-based method overcomes the limitations of phylotype-based method and permits the classification of OTUs down to the species level, as typically an OTU is thought of as representing a species, and for this the OTU-based method necessarily relies on a reference data set including species.

\texttt{eudysbiome} applies the OTU-based classification by mapping OTUs' unclassified \emph{representative} sequences (produced via microbiome analysis pipelines such as emph{Mothur}\cite{Schloss2009} or \emph{QIIME}\cite{Caporaso2010} during the generation of the OTUs) to a selection of classified representative sequences of OTUs, obtained from clustering the truncated \emph{SILVA}\cite{silva} Small subunit (16S/18S, SSU) ribosomal RNA (rRNA) reference dataset at 97\% similarity. This representative dataset is built within QIIME and included in our package. In this mapping, each entry in the representative dataset is associated to a taxonomic path containing the taxonomy rank designations from kingdom to species.

In order to translate the GI microbiome variations into potential clinical interpretation, it is helpful to assess whether the variation leads towards a microbiome that is more or less synergistic with the host, i.e. more or less pathogenic. To achieve this goal, in addition to the standard taxonomic annotation (\texttt{classification}, from now on) described above, this package annotates species as \texttt{harmful/harmless} based on their ability to contribute to mammals' host diseases (as indicated in literature) and hence based on their pathogenic potential (\texttt{annotation} from now on).
Several assumptions are needed to achieve this goal, due to the quickly growing, but still limited amount of information currently available on microbes in our GI.
First, the number of unknown (uncultured, ambiguous, unclassified, etc.) species resulting from the classification process leads to the practical
impossibility to assess the pathogenic potential directly on the annotated species. For this reason, the analysis is run at the genus level, annotated based on the annotated species. The rationale used throughout the annotation process relies on the assumption that larger and successful efforts have been devoted to the study of pathogens, and we have observed that classified species that are not explicitly (literature based) annotated as \texttt{harmful}, can be safely annotated as \texttt{harmless}.
Genera are then further annotated as harmful, in a conservative fashion, if at least one species in the genus is pathogenic or less pathogenic otherwise. This outputs the reference table \texttt{harmGenera} offered in the package, and allows for direct annotation of classified genera.
However, to achieve a more precise annotation, it is recommended to provide (or compute via our package \texttt{tableSpecies} function) the data frame genus-species, to control for the very stringent harmful annotation. In fact, if, in the data to be analyzed, species are provided in addition to the genus, the package checks whether the genera defined as harmful in the annotation table actually include the harmful species. In this case the genus is coherently annotated as harmful. However, if the harmful species are not present in the data to be analyzed, the genus provides in fact a harmless contribution, and it is annotated as such. Similarly, if the genus turns out to include none known species, we discard the one listed in the harmGenera table from the analysis while annotate the others as harmless.

Finally, the package statistically measures the \texttt{eubiotic} (harmless genera increase or harmful genera decrease) or \texttt{dysbiotic} (harmless genera decrease or harmful genera increase) relevance of a given treatment or environmental change in terms of its ability to modify the harmful/harmless frequencies.



\begin{itemize}
\item The package requires as inputs:
\begin{itemize}
\item a FASTA-formatted 16S rRNA sequence file to be classified to the species level;
\item the list of microbe genera, for example, a list of differential genera identified by the comparative analysis to be annotated as \texttt{harmful/harmless};
\item the microbial abundance variations, a simple difference of the differential genera abundance (defined as $\Delta$g) in the two conditions to be compared, as defined above in \hyperref[sec:introduction]{Introduction};
\item a table qualifying the genera as \texttt{harmful}/\texttt{harmless}, as defined by literature. Such a table, manually curated, is included in this package, but is by no means exhaustive: continuous advances in microbiology make this input incomplete and flexible; we encourage users to share expansions of this table.
\end{itemize}

\item The package outputs:
\label{itm:ouput}
\begin{itemize}
\item Species-classification results, a \texttt{*.taxonomy} file which contains a taxonomic path for each 16S rRNA sequence and a \texttt{*.tax.summary} file which contains a taxonomic outline indicating the number of sequences that were found at each level (kingdom to species);
\item optional, a two-column Genus-Species data frame extracted from the assigned taxonomic paths in \texttt{*.taxonomy} file, which includes only the differential genera (as \emph{inputs});
\item a graphical output of the genus abundance difference-$\Delta$g across the tested conditions (y-axis) and their harmful/harmless nature (negative/positive x-axis);
\item a contingency table showing as frequencies the cumulated contributions to an eubiotic/dystbiotic microbiome (see Table~\ref{tab:contingency}, columns, namely \texttt{EI} and \texttt{DI}) under different conditions (comparisons between a condition and a reference, listed in rows, namely \texttt{C1} and \texttt{C2}). The eubiotic impact (EI) is quantified by the |$\Delta$g| cumulation of increasing harmless genera and decreasing harmful genera, while the dysbiotic impact (DI) is quantified by the reverse, i.e. |$\Delta$g| accumulation of decreasing harmless genera and increasing harmful genera;
\item the results (probability) of testing the null hypothesis that there is no difference in the proportions of frequencies of \texttt{EI} between \texttt{C1} and \texttt{C2} using Fisher exact test (two sided) or Chi-squared test\cite{Rice2007}, computed as the probability that the proportion of frequencies in \texttt{EI} under \texttt{C1} ($\frac{a}{a+b}$) is different from that in \texttt{DI} under \texttt{C2} ($\frac{c}{c+d}$). The results of the one-sided Fisher's exact test\cite{Rice2007} assess whether \texttt{C1} is more likely to be associated to a eubiotic microbiome than \texttt{C2}, and is computed as the probability that the proportion of EI under \texttt{C1} is higher than \texttt{C2}.
\end{itemize}
\end{itemize}

\begin{table}
\centering
\begin{tabular}{c c c c}
\hline\hline
Comparison & EI & DI & \emph{Row Total} \\ [0.5ex]
\hline
C1 & \emph{a} & \emph{b} & \emph{a+b} \\
C2 & \emph{c} & \emph{d} & \emph{c+d} \\
\hline
\emph{Column Total} & \emph{a+c} & \emph{b+d} & \emph{a+b+c+d(=n)} \\
\hline
\end{tabular}
\caption{Contingency Table}
\label{tab:contingency}
\end{table}

\section*{Methods}
\section{Representative Sequences}
\label{sec:repre}
To achieve the Species-level classification, we recommend classifying the unknown 16S rRNA sequences to a well-curated representative dataset of 16S rRNA reference sequences, such as Greengene and SILVA representative sets (as recommended by \emph{Mothur} with very stringent 99\% similarity and \emph{QIIME} with 97\% similarity ). We here use the SILVA representative set created by clustering at 97\% sequence identity, to guarantee a fast Species-level classification and also require less computational resources when assigning sequences to a reference dataset, both requirements are crucial to allow automation of this classification step, as we offer in this package. The representative dataset ``Silva\_119\_rep\_set97.fna" is downloaded in latest version SILVA119 provided by QIIME team from  (\href{https://www.arb-silva.de/no_cache/download/archive/qiime}{https://www.arb\-silva.de/no\_cache/download/archive/qiime}). A taxonomic mapping file ``Silva\_119\_rep\_set97\_taxonomy.txt", mapping each entry in the representative dataset to a taxonomy rank designation, was also downloaded and prepared into the input format to \emph{Mothur}, which is included in our package for the usage of further sequence classification.

\section{Taxonomy Assignment}
\label{sec:assign}

The assignment requires a FASTA-formatted input of unclassified sequence, a representative sequence file and a taxonomic mapping file for the representative sequences(Section~\ref{sec:repre}). Given a set of unclassified 16S rRNA sequences, e.g. a set of OTU representative sequences, we assign the taxonomic paths to these sequences by calling the \texttt{classify.seqs} command in  \emph{Mothur} (\href{http://www.mothur.org/}{http://www.mothur.org/}). Of the two alternative methods (\texttt{Wang} and \texttt{k-Nearest Neighbor (knn)}) provided in the \texttt{classify.seqs} command for the taxonomic assignment, we use \texttt{\emph{Wang}}'s, implemented by the RDP classifier. This method queries both the unclassified and reference sequences k-mer by k-mer (subsequences of length k) and assigns the unclassified sequences to the appropriate taxa based on the highest matching probability. To calculate the confidence of the assignments, bootstrapping by random replacement of 1/8 (k = 8) of the k-mers in the unclassified sequence is used.

<<eval=FALSE>>=
library("eudysbiome")
input.fasta = "Unclassified.fasta"
# using the extracted fasta and taxonomy as template
assignTax(fasta = input.fasta,ksize = 8, iters = 100,
                       cutoff = 80, processors=1, dir.out = "assignTax_out")
@

The parameters, \texttt{k-size} (length k), \texttt{iterates} (bootstrap iterations) and \texttt{processors} (number of central processing units) are used as defaults in \emph{Mothur}. We set a cutoff of bootstrap confidence score to 80, which means a minimum 80\% sequences were assigned to the same taxonomy, a higher value gives a more strict and accurate taxonomy assignment. A \texttt{*.taxonomy} file and a \texttt{*.tax.summary} file of the classification results are outputd into the \texttt{assginTax} directory.

\newpage
\section{Genus-Species Table Construction}
\label{sec:speciesTable}
To identify only the species under certain genera from the \texttt{*.taxonomy} file, the \texttt{tableSpecies} function constructs a two-column Genus-Species data frame, where one column refers to the provided genera while the other refers to the species included in these genera.

<<>>=
genera = c("Lactobacillus","Bacteroides")
#species = tableSpecies(tax.file = "*.taxonomy", microbe = genera)
@

\section{Microbe Annotation}
\label{sec:microAnnotate}
A differential genera list (input) can be annotated as \texttt{harmless} or \texttt{harmful} by the function \texttt{microAnnotate} based on our manually curated table named \texttt{harmGenera} in this package. The table lists the harmful genera based on the pathogenic or opportunistic pathogenic species included in the genera, using a stringent approach: one armful species is sufficient to define the genus harmful (this is what indeed matters to the eubiotic/dysbiotic trend). Although a genus list is acceptable and can be processed with this genera annotation table, we recommend inputting for the data to be analyzed the Genus-Species data frame, as in the \texttt{diffGenera} table below to gain a more accurate annotation.
In fact, if the species abundances are known, it is possible to discard a genus in case none of the taxonomically annotated species is present in the dataset (only unknown ones), or mark as harmless a genus that would be harmful by annotation table, in case the harmful species is not present in the dataset under study. For example, genus1 will be annotated as harmful if any of the three species (1, 2 and 3) under this genus is annotated as \texttt{harmful}, otherwise, genus1 will be annotated as \texttt{harmless}. For the data lacking of Species-level classifications, we suggest to do the classification and construct such a Genus-Species table for better annotation by functions described above (Section~\ref{sec:speciesTable}).

<<>>=
library("eudysbiome")
data(diffGenera)
head(diffGenera)

data(harmGenera)
annotation = microAnnotate(diffGenera, annotated.micro = harmGenera)
@

\section{Cartesian Plane Plot}
\label{sec:Cartesian}
The function \texttt{Cartesian} accepts either a data frame or a numeric matrix of $\Delta$g, whose rows represent differential genera and columns represent condition comparisons, these are the argument to produce the cartesian plane (4 quadrants (see details below and in Figure~\ref{fig:carte1} below). The $\Delta$gs are log-2 converted and redundantly represented by the height on the y-axis and the dots diameter. Because of its definition, the increase of harmless (1st cartesian quadrant) and/or the decrease of harmful (3rd cartesian quadrant) define microbiome variation that are eubiotic (beneficial) and highlighted by a blue box, and the decrease of harmless (2nd quadrant) and/or the increase of harmful (4th quadrant) as dysbiotic (non-beneficial) and highlighted by a yellow box. The unknown genera are removed from the plot.

For example below, a data frame \texttt{data} is constructed from the \texttt{microDiff} dataset with $\Delta$g of ten differential genera among comparisons \texttt{A vs C}, \texttt{B vs C} and \texttt{D vs C}, where \texttt{A}, \texttt{B} and \texttt{D} are three conditions and \texttt{C} is a control. The genera are annotated as \texttt{harmless}, \texttt{harmful} or \texttt{unknown} in \texttt{micro.ano} based on the output by the \texttt{microAnnotate} function, and comparisons are defined as \texttt{A-C} (A vs C), \texttt{B-C} (B vs C), and \texttt{D-C} (D vs C) in \texttt{comp.ano} and indicated by the column names of the input data if no other \texttt{comp.anno} is specified. Eubiotic changes associated to conditions \texttt{A, B, D} compared to control \texttt{C} are plotted in the up-utmost right and bottom-utmost left quadrants (increase of harmless and decrease of harmful genera) and dysbiotic variations are plotted on the bottom-utmost right and up-utmost left quadrants (increase of harmful and decrease of harmless genera) in Figure~\ref{fig:carte1}.

<<Cartesian, fig=TRUE, include=FALSE,  prefix=FALSE, cache=TRUE >>=
data(microDiff)
microDiff
attach(microDiff)

par(mar = c(5,4.1,5.1,5))
Cartesian(data ,micro.anno = micro.anno,comp.anno= comp.anno,
                unknown=TRUE,point.col = c("blue","purple","orange"))
@

\begin{figure}
\centering
\includegraphics[height=0.9\textwidth, width=0.9\textwidth]{Cartesian}
\caption{\label{fig:carte1} Cartesian plane of the harmful/harmless annotated genera (on the x-axis) and their abundance variations among the condition comparisons (log2 ($\Delta$g), y-axis). The eubiotic microbiome impact is highlighted by a dark blue box while the dysbiotic one is highlighted by a yellow box.}
\end{figure}

\newpage
\section{Contingency Table Construction}
This function computes the frequencies of the contingency table as the cumulated |$\Delta$g| classified by each couple formed by a condition and an impact (eubiotic/dysbiotic, see Table~\ref{tab:contingency}). This outputs the significance of the association (contingency) between conditions and impacts by \texttt{contingencyTest}. For example, the benefits of conditions \texttt{A, B, D} are measured by the increase $\Delta$g of harmless genera and the decrease $\Delta$g of harmful genera in the comparisons to \texttt{C}, while the non-beneficial impact is evaluated in reverse by the decrease $\Delta$g of harmless genera and the increase $\Delta$g of harmful genera. Absolute values of $\Delta$g are cumulated as frequencies and used into the contingency table (Table~\ref{tab:Count}).

<<microCount,fig=FALSE>>=
microCount = contingencyCount(data ,micro.anno = micro.anno,
                              comp.anno= comp.anno)
@

\begin{table}
\centering
\begin{tabular}{c c c}
\hline\hline
Condition & Eubiotic Impact & Dysbiotic Impact \\ [0.5ex]
\hline
A-C & 2068 & 315 \\
\hline
B-C & 2270 & 313 \\
\hline
D-C & 1369 & 264 \\
\hline
\end{tabular}
\caption{Condition-impact contingency table of microbial frequencies}
\label{tab:Count}
\end{table}


\section{Contingency test for count data}
To elaborate the significance of the association between conditions and eubiotic/dysbiotic impacts, Chi-squared test and Fisher's exact test (one- and two- sided) are performed on the frequencies from \texttt {contingencyCount} for testing the null hypothesis that conditions are equally likely to lead to a more eubiotic microbiome when compared to the control while the alternative hypothesis is that this probability is not equal or one condition is more likely to be associated to an eubiotic microbiomes than the other (only with Fisher test, one-sided).
Taking Table~\ref{tab:Count} as an example, we hypothesize that the proportion of eubiotic frequencies are different (Chi-squared and two-sided Fisher test) between condition comparisons \texttt{A-C}, \texttt{B-C} and \texttt{D-C} or even higher (one-sided Fisher test) in one comparison than the other, and we want to test whether this difference is negligible or refers to a significant association between the condition and the (GI) microbiome composition modification. Both Fisher and Chi-squared tests are performed by the \texttt{contingencyTest} function and significance values are output in tables.

<<test,fig=FALSE>>=
microTest = contingencyTest(microCount,alternative ="greater")
microTest["Chisq.p"]
microTest["Fisher.p"]
@

\newpage
\begin{thebibliography}{9}
\bibitem{Schloss2011}
Patrick D. Schloss, et al.
Assessing and Improving Methods Used in Operational Taxonomic Unit-Based Approaches for 16S rRNA Gene Sequence Analysis.
\emph{Applied and Environmental Microbiology}
2011;
77(10): p. 3219-3226

\bibitem{Schloss2009}
Patrick D. Schloss, et al.
Introducing mothur: Open-Source, Platform-Independent, Community-Supported Software for Describing and Comparing Microbial Communities.
\emph{Applied and environmental microbiology}
2009;
75(23): 7537-7541.

\bibitem{Caporaso2010}
J Gregory Caporaso, et al.
QIIME allows analysis of high-throughput community sequencing data.
\emph{Nature Methods}
2010;
7(5):335-336.

\bibitem{silva}
Quast C.,et al.
The SILVA ribosomal RNA gene database project:improved data processing and web-based tools.
\emph{Nucleic Acids Research}
2013;
41(D1):D590-D596

\bibitem{Rice2007}
Rice, John A.,
Mathematical statistics and data analysis,
Belmont, CA,
Thomson/Brooks/Cole,
Duxbury advanced series,
3rd,
2007.

\end{thebibliography}

\section*{Session Information}
The session information records the versions of all the packages used in the generation of the present document.
\scriptsize{
<<sessionInfo,results=tex,echo=FALSE>>=
toLatex(sessionInfo())
@
}

\end{document}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/contingencyCount.R
\name{contingencyCount}
\alias{contingencyCount}
\title{Contingency Table Construction}
\usage{
contingencyCount(x, micro.anno=NULL, comp.anno=NULL)
}
\arguments{
\item{x}{See \code{x} in \code{\link{Cartesian}}, the x values should be difference values without log converted.}

\item{micro.anno}{See \code{micro.anno} in \code{\link{Cartesian}}.}

\item{comp.anno}{See \code{comp.anno} in \code{\link{Cartesian}}.}
}
\value{
The frequencies of condition-impact terms in contingency table
}
\description{
Computes the frequencies of the contingency table as the cumulated microbial abundance difference classified into each condition and eubiotic/dysbiotic impact term for examining the significance of the association (contingency) between conditions and impacts by  \code{\link{contingencyTest}}.
}
\details{
Eubiotic impact is measured by variations of increased harmless and decreased harmful microbes, while the dysbiotic impact is measured by the decreased harmless and increased harmful microbes.
}
\examples{
data(microDiff)
attach(microDiff)

microCount = contingencyCount(x = data, micro.anno = micro.anno,
                      comp.anno = comp.anno)

detach(microDiff)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/eudysbiome.R
\docType{data}
\name{diffGenera}
\alias{diffGenera}
\title{Differential microbes in Genus-Species table
A data frame containing 10 differential genera and the species included, which was to be annotated as \code{"harmful"} or \code{"harmless"}.}
\format{A data frame with 26 rows and 2 columns specifying for \code{Genus} and \code{Species}.}
\usage{
data(diffGenera)
}
\description{
Differential microbes in Genus-Species table
A data frame containing 10 differential genera and the species included, which was to be annotated as \code{"harmful"} or \code{"harmless"}.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Cartesian.R
\name{Cartesian}
\alias{Cartesian}
\title{2-D Cartesian plane Plots}
\usage{
Cartesian(x,log2 = TRUE,micro.anno = NULL, comp.anno = NULL,
             pch = 16, point.col = NULL,point.alpha = 0.6,ylim = NULL, 
             xlab = NULL,ylab = NULL,vlty = 2, hlty = 1, srt = 60,
             font = 3, adj = c(1,1), xaxis = NULL, yaxis = NULL, legend = TRUE,
             box = TRUE,box.col = c("darkblue","yellow"),
             ...)
}
\arguments{
\item{x}{a data frame or numeric matrix of microbial abundance variations from which the plot is produced. Rows indicate the differential microbes, columns indicate the pair-wise conditions. \code{x} values can either be difference values or be \emph{log2} converted, specified with \code{log2} parameter.}

\item{log2}{logical, specifying if x values should be \emph{log2} converted; default to \code{TRUE}.}

\item{micro.anno}{a character vector to annotate all row microbes in \code{x}; e.g. \code{"harmless"},\code{"harmful"}, should be in same length with the microbes. It can be given by the output of \code{\link{microAnnotate}}}

\item{comp.anno}{a character vector of conditions pre-defined from the column pair-wise comparisons, should be in same length with the comparisons; default to the pair-wise comparisons.}

\item{pch}{a vector of point types. Graphical parameters:see \code{\link[graphics]{par}}.}

\item{point.col}{a vector of colors for the points.}

\item{point.alpha}{alpha value for points; see \code{\link[grDevices]{adjustcolor}}.}

\item{ylim}{limits for the y axis.}

\item{xlab}{a title for the x axis.}

\item{ylab}{a title for the y axis.}

\item{vlty, hlty}{types of vertical and horizontal lines to divide the plane with x-axis and y-axis, respectively.}

\item{srt, font, adj}{graphical parameters for the text on x-axis, see \code{\link[graphics]{par}}.}

\item{xaxis}{a character or expression vector specifying the labels of x axis by \emph{text}; default to row names of \code{x}.}

\item{yaxis}{a character or expression vector specifying the labels of y axis by \emph{axis}; default to \code{at} values in \code{\link[graphics]{axis}}.}

\item{legend}{logical, specifying if the legend should be added to the plot; default to \code{TRUE}.}

\item{box}{logical, specifying if the quadrants should be highlighted by boxes; default to \code{TRUE}.}

\item{box.col}{a vector of colors for the  up-utmost right, bottom-utmost left quadrants and bottom-utmost right, up-utmost left quadrants, respectively; default to "darkblue" and "yellow". If only one color is specified, the other one can be \code{NA}.}

\item{...}{additional parameters passed to the default method, or by it to \code{\link[graphics]{plot.window}}, \code{\link[graphics]{text}},\code{\link[graphics]{mtext}},\code{\link[graphics]{axis}}, and \code{\link[graphics]{title}} to control the appearance of the plot.}
}
\value{
The Cartesian plane plot
}
\description{
This function plots a Cartesian plane of genus abundance difference across the tested conditions (y-axis) and their harmful/harmless nature (negative/positive x-axis), giving rise to up-utmost right and bottom-utmost left quadrants of microbial eubiotic impact and bottom-utmost right and up-utmost left quadrants of dysbiotic impact.
}
\examples{
data(microDiff)
attach(microDiff)

newpar = par()
par(mar = c(6,5.1,4.1,6))
Cartesian(x = data,log2 = TRUE,micro.anno = micro.anno,pch = 16,
         comp.anno = comp.anno,point.col = c("blue","purple","orange"))

par(newpar)
detach(microDiff)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tableSpecies.R
\name{tableSpecies}
\alias{tableSpecies}
\title{Construct a Genus-Species Data Frame}
\usage{
tableSpecies(tax.file, microbe)
}
\arguments{
\item{tax.file}{a taxonomy file with SSU rRNA sequence names and assigned taxonomic paths, see "*.taxonomy" file outputted by \code{\link{assignTax}}.}

\item{microbe}{a character vector specifying the genera used to construct the Genus-Species data frame}
}
\value{
a Genus-Species data frame, only with the genera specified by \code{microbe} and the included corresponding species .
}
\description{
This function is used to extract only Genus-Species data from the assigned taxonomic paths outputted by \code{\link{assignTax}} and construct a table containing the classified genera and species included in these genera correspondingly.
}
\details{
The outputted Genus-Species table can be used as input for the more accurate genus annotation, which annotates genera as \code{harmful} or \code{harmless} based on their ability to contribute to mammals' host diseases by \code{\link{microAnnotate}}.
}
\examples{
#a table with "Lactobacillus" and "Bacteroids" genera and the included species
genera = c("Lactobacillus","Bacteroides")
#not excute
#tableSpecies(tax.file = "test.taxExtract.wang.taxonomy", microbe = genera)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/eudysbiome.R
\docType{data}
\name{harmGenera}
\alias{harmGenera}
\title{Manually curated genera annotation table
A data frame containing 260 genera annotated as "harmful" and the harmful species included in these genera.}
\format{A data frame with 900 rows and 3 columns specifying for \code{Genus} and \code{Species} and the references.}
\usage{
data(harmGenera)
}
\description{
Manually curated genera annotation table
A data frame containing 260 genera annotated as "harmful" and the harmful species included in these genera.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/contingencyTest.R
\name{contingencyTest}
\alias{contingencyTest}
\title{Contingency test for count data}
\usage{
contingencyTest(microCount, chisq = TRUE, fisher = TRUE,
                alternative = c("greater"))
}
\arguments{
\item{microCount}{a \emph{m by 2} data frame or numeric matrix of contingency table with frequencies under each condition-impact term; could be produced from \code{\link{contingencyCount}}.}

\item{chisq, fisher}{logical indicating if the Chi-squared test or Fisher's exact test should be performed.}

\item{alternative}{parameter specifying for alternative hypothesis, only used when \code{fisher} is \code{TRUE}; see \code{\link[stats]{fisher.test}}.}
}
\value{
A list with following components:
Chisq Chi-squared test results for each pair-wise condition.
Chisq.p the p-values of the Chi-squared tests for all pair-wise conditions.
Fisher Fisher's exact test results for each pair-wise condition.
Fisher.p the p-values of the Fisher's exact tests for all pair-wise conditions.
}
\description{
Performs Chi-squared test or Fisher's exact test for testing the significance of association between conditions and eubiotic/dysbiotic impacts in a contingency table.
}
\details{
Chi-squared test for testing the probability that  the proportions of eubiotic frequencies are different between two conditions; furtherly, the Fisher's exact test for testing whether one condition is more likely to be associated to eubiotic impact. More details, refer to \code{\link[stats]{chisq.test}} and \code{\link[stats]{fisher.test}}
}
\examples{
data(microCount)

test = contingencyTest(microCount,chisq = TRUE,fisher = TRUE,
           alternative = "greater")
chisq.p = test[["Chisq.p"]]
fisher.p = test[["Fisher.p"]]
}
\seealso{
\code{\link{contingencyCount}}, \code{\link[stats]{fisher.test}}, \code{\link[stats]{chisq.test}}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/eudysbiome.R
\docType{data}
\name{microDiff}
\alias{microDiff}
\title{Differential annotated genera with abundance variations among pair-wise condition comparisons}
\format{A list}
\usage{
data(microDiff)
}
\description{
A list containing: i) a data frame of 10 differentila genera with abundance differences among 3 condition comparisons, in which row represents the differential microbes and column represents the comparisons; ii) Genera annotations for the 10 differential genera; iii) pre-defined condition comparison names
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/microAnnotate.R
\name{microAnnotate}
\alias{microAnnotate}
\title{Genus Annotation}
\usage{
microAnnotate(microbe, species = TRUE, annotated.micro = NULL)
}
\arguments{
\item{microbe}{a genus list to be annotated; a Genus-Species data frame which represents the genera and the included corresponding species is recommended to be provided by users for the more accurate annotations, see \code{\link{tableSpecies}}.}

\item{species}{logical, specifying if the species are provided in the \code{microbe} for the annotations; default to \code{TRUE}.}

\item{annotated.micro}{the annotated genera which are used for the annotation of \code{microbe}, it could either be loaded from the data \code{harmGenera} or defined by users.}
}
\value{
The annotated genera.
}
\description{
Annotates given genera as harmful or harmless based on either our manually curated, harmful Genus-Species table in data \code{harmGenera} of this package or user defined table.
}
\examples{
#load the genera to be annotated
library(eudysbiome)
data(diffGenera)

#load the curated Genus-Species annotation table
data(harmGenera)

microAnnotate(microbe = diffGenera, species = TRUE,
           annotated.micro = harmGenera)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/assignTax.R
\name{assignTax}
\alias{assignTax}
\title{Taxonomic Classification}
\usage{
assignTax(fasta, template = NULL, taxonomy = NULL, ksize = 8, iters = 100, cutoff = 80,
processors = 1, dir.out = "assignTax_out")
}
\arguments{
\item{fasta}{a fasta file of rRNA sequences to be assigned with taxonomies, e.g. a set of sequences picked as the representatives of OTUs.}

\item{template}{a faste file of rRNA reference sequences, default to download "Silva_119_provisional_release.zip" under "qiime" directory from SILVA archive under , and extract "Silva_119_rep_set97.fna", a representative set of SILVA rRNA references of version119 at 97\% sequence identity.}

\item{taxonomy}{a taxonomic path file mapping to the template file, default to load "Silva_119_rep_set97.fna" matched "taxonomy" stored in the package.}

\item{ksize, iters, cutoff, processors}{parameters used in \href{http://www.mothur.org/wiki/Classify.seqs}{Classify.seqs} by Mothur. \code{ksize}, kmer size which is a search option with the 'Wang' method and by default to 8.  \code{iters}, iterations by default 100 to calculate the bootstrap confidence score for the assigned taxonomy. \code{cutoff}, a bootstrap confidence score for the taxonomy assignment, by default 80, which means a minimum 80\% sequences were assigned by the same taxonomy, a higher value gives a more strict taxonomy assignment. \code{processors}, the number of central processing units you use to run the command, by default to 1.}

\item{dir.out}{a directory where the assigned files were outputted, by default to create \code{assignTax_out} directory and output assigned files under this directory.}
}
\value{
two files under \code{dir.out}, a \code{*.taxonomy} file which contains a taxonomic path for each sequence and a \code{*.tax.summary} file which contains a taxonomic outline indicating the number of sequences that were found at each level (kingdom to species).
a list containing the following components:
exitStatus  an error code ('0' for success) given by the execution of the system Mothur commands, see \code{\link[base]{system}}.
stderr, stdout standard errors and outputs by executing Mothur command 'classify.seqs'.
}
\description{
Assign taxonomic paths to unclassified SSU rRNA sequences, by executing \code{classify.seqs} in \href{http://www.mothur.org/}{Mothur} with the 'Wang' approach.
}
\details{
This function performs 'classify.seqs' by running Mothur in command line mode, hence the executable Mothur on your computer is needed. For unix users, the absolute path of Mothur should be added to the PATH environmental variable and exported. For Windows users, the executable Mothur with extension .exe is required under your disks.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/eudysbiome.R
\docType{data}
\name{microCount}
\alias{microCount}
\title{Microbial count contingency table}
\format{A data frame with 2 rows and 2 variables}
\usage{
data(microCount)
}
\description{
A matrix containing the counts of differential microbe classified into each condition-eubiotic/dysbiotic impact couple. Rows represent the condition comparisons, columns represent the eubiotic and dysbiotic impacts:
}
\details{
\itemize{
  \item EI. eubiotic impact
  \item DI. dysbiotic impact
}

The table can be produced by \code{\link{microCount}} function.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/eudysbiome.R
\docType{package}
\name{eudysbiome}
\alias{eudysbiome}
\alias{eudysbiome-package}
\title{eudysbiome.}
\description{
eudysbiome.
}
